from fastapi import APIRouter, Depends
from sqlalchemy.orm import Session

from app.database.session import get_db

router = APIRouter()


@router.get("", response_model=dict)
def health_check(db: Session = Depends(get_db)):
    """
    Health check endpoint to verify API and database are working
    """
    try:
        # Check if DB connection is working
        db.execute("SELECT 1")
        return {
            "status": "ok",
            "message": "API is healthy and database connection is working"
        }
    except Exception as e:
        return {
            "status": "error",
            "message": f"Database connection failed: {str(e)}"
        }